@@ -88,7 +88,7 @@ class Database:
 
 
 class Atom:
-    def __init__(self, name, elims=(1000, 120000)):
+    def __init__(self, name, elims=(1200, 120000)):
         """
         Initialises Atom class. 
         Arguments:
@@ -140,7 +140,6 @@ class Atom:
            barnxs[kk] = icurve
            cmxs[kk] = icurve_ua
         return barnxs, cmxs
-        #return sig_tot, sig_tot_ua, sig_el_ua
 
 
 class Mixture:
@@ -169,7 +168,7 @@ class Mixture:
         logger.info('%s formula weight: %.4f g/mol.' % (formula, self.fw))
         logger.info('Input density: %.4f g/cm^3' %(self.prop['d']))
 
-    def mix_mu(self, energy, thickness_cm=0.01, components=0):
+    def mix_mu(self, energy, thickness_cm=0.01):
         """
         Calculate values for a single energy value. Print output similar to the APS website.
         Arguments:
@@ -188,34 +187,19 @@ class Mixture:
         logger.info('X-ray energy (wavelength): %d eV (%.5f A)'\
                     %(energy, 12398.4/energy))
         logger.info('Sample thickness: %.5f cm' %(self.thick))
-        logger.info(f"""{'atom':<7s} {'wt frac':<7s} {"f'":<7s} {"f''":<7s} {'total xs':<8s} {'rayleigh':<8s} {'compton':<8s} {'photoelectric':<15s} {'phot+compton':<15s}""")
+        logger.info(f"""{'atom':<8s} {'wt frac':<8s} {"f'":<8s} {"f''":<8s} {'total xs':<15s} {'rayleigh xs':<15s} {'compton xs':<15s} {'photoelectric xs':<15s}""")
         for w in self.stoi.keys():
             u = Atom(w)
             barnxs, cmxs = u.atom_mu(energy)
-            if components == 0:
-               #label = 'Total'
-                sig_ua = cmxs['tot']
-            elif components == 1:
-               #label = 'Photoelectric+Compton'
-                sig_ua = cmxs['pe']+cmxs['co']
-            elif components == 2:
-               #label = 'Rayleigh'
-                sig_ua = cmxs['ra']
-            elif components == 3:
-               #label = 'Photoelectric'
-                sig_ua = cmxs['pe']
-            elif components == 4:
-               #label = 'Compton'
-                sig_ua = cmxs['co']
+            sig_ua = cmxs['tot']
             mix_sigma += sig_ua*self.weig[u.name]
             f1, f2 = u.atom_ff(energy)
-            logger.info('%-7s %-7.3f %-7.3f %-7.3f %-8.3f %-8.3f %-8.3f %-15.3f %-15.3f' \
+            logger.info('%-8s %-8.3f %-8.3f %-8.3f %-15.3f %-15.3f %-15.3f %-15.3f' \
                  %(u.name, self.weig[u.name], f1, f2,
                    barnxs['tot']*self.stoi[u.name],
-                   (barnxs['pe']+barnxs['co'])*self.stoi[u.name],
                    barnxs['ra']*self.stoi[u.name],
-                   barnxs['pe']*self.stoi[u.name],
-                   barnxs['co']*self.stoi[u.name]) )
+                   barnxs['co']*self.stoi[u.name],
+                   barnxs['pe']*self.stoi[u.name]) )
         self.mu = np.multiply(mix_sigma, self.prop['d'])
         self.transm = np.exp(-self.mu*self.thick)
         logger.info('Total mu = %.2f cm^-1' %(self.mu))
@@ -224,7 +208,7 @@ class Mixture:
         return self.transm, f1, f2
 
 
-    def mix_mue(self, energy, thickness_cm=0.01, components=0):
+    def mix_mue(self, energy, thickness_cm=0.01):
         """
         Calculate values for an array of energy values. No atom-wise print output.
         Arguments:
@@ -239,7 +223,8 @@ class Mixture:
         """
         logger = logging.getLogger(__name__)
         self.thick = thickness_cm
-        mix_sigma = np.zeros(len(energy))
+        mix_total = np.zeros(len(energy))
+        mix_rayl, mix_comp, mix_phoe = np.zeros(len(energy)), np.zeros(len(energy)), np.zeros(len(energy))
         f1, f2 = np.zeros(len(energy)), np.zeros(len(energy))
         logger.info('X-ray energy (wavelength): %d-%d eV (%.5f-%.5f A)'\
                     %(energy[0], energy[-1], 12398.4/energy[0], 12398.4/energy[-1]))
@@ -247,44 +232,25 @@ class Mixture:
         for w in self.stoi.keys():
             u = Atom(w)
             barnxs, cmxs = u.atom_mu(energy)
-            if components == 0:
-               #label = 'Total'
-                sig_ua = cmxs['tot']
-            elif components == 1:
-               #label = 'Photoelectric+Compton'
-                sig_ua = cmxs['pe']+cmxs['co']
-            elif components == 2:
-               #label = 'Rayleigh'
-                sig_ua = cmxs['ra']
-            elif components == 3:
-               #label = 'Photoelectric'
-                sig_ua = cmxs['pe']
-            elif components == 4:
-               #label = 'Compton'
-                sig_ua = cmxs['co']
-            mix_sigma += sig_ua*self.weig[u.name]
+            mix_total += cmxs['tot']*self.weig[u.name]
+            mix_rayl += cmxs['ra']*self.weig[u.name]
+            mix_comp += cmxs['co']*self.weig[u.name]
+            mix_phoe += cmxs['pe']*self.weig[u.name]
             f1_w, f2_w = u.atom_ff(energy)
             f1 += f1_w; f2 += f2_w
-        self.mu = np.multiply(mix_sigma, self.prop['d'])
+        self.mu = np.multiply(mix_total, self.prop['d'])
         self.transm = np.exp(-self.mu*self.thick)
-        logger.info("""Energy--|-%Transm--|--muR---|---mu---|---f'---|--f''---""")
+        logger.info(f"""{'energy':<8s} {'% transm':<8s} {'mu:<8s'} {'muR':<8s} {"f'":<8s} {"f''":<8s} {'total xs':<15s} {'rayleigh xs':<15s} {'compton xs':<15s} {'photoelectric xs':<15s}""")
         for i in range(len(energy)):
-            logger.info('%8d|%10.3f|%8.3f|%8.3f|%8.3f|%8.3f' %(energy[i], 
-                                             100*self.transm[i], 
-                                             self.mu[i]*0.5*self.thick, 
-                                             self.mu[i], f1[i], f2[i]))
+            logger.info('%8d|%10.3f|%8.3f|%8.3f|%8.3f|%8.3f' \
+                        %(energy[i], 100*self.transm[i], self.mu[i], self.mu[i]*0.5*self.thick, f1[i], f2[i],
+                          mix_total[i], mix_rayl[i], mix_comp[i], mix_phoe[i]) )            
         return self.transm, f1, f2
 
 
 def console():
     #thelogger = Logg(__name__)
     thelogger = logging.getLogger(__name__)
-    components_help = 'Use total cross section or partial: \
- 0 = total; \
- 1 = photoelectric + Compton; \
- 2 = only Rayleigh (coherent); \
- 3 = only photoelectric; \
- 4 = only Compton (incoherent)'
      ##--argument parser
     parser = argparse.ArgumentParser(description='X-ray absorption calculation')
     parser.add_argument('-f', type=str,
@@ -299,8 +265,6 @@ def console():
                         help='X-ray energy in eV. Single value or <start> <step> <end>.', nargs='+')
     parser.add_argument('-t', type=float,
                         help='Sample thickness (diameter) in mm')
-    parser.add_argument('-y', type=int, default=0, help=components_help,
-                        choices=[0,1,2,3,4])
     parser.add_argument('-l', type=int,
                         help='Display information: 0=OFF, 1=ON (default)',
                         default=1)
@@ -321,13 +285,13 @@ def console():
      ##--calculate
     t_cm = 0.1*args.t
     if len(args.e) == 1:
-        sk.mix_mu(args.e[0], t_cm, bool(args.y))
+        sk.mix_mu(args.e[0], t_cm)
     elif len(args.e) == 2:
-        sk.mix_mu(args.e[0], t_cm, bool(args.y))
-        sk.mix_mu(args.e[1], t_cm, bool(args.y))
+        sk.mix_mu(args.e[0], t_cm)
+        sk.mix_mu(args.e[1], t_cm)
     elif len(args.e) >=3:
         ene = np.arange(args.e[0], args.e[2]+args.e[1], args.e[1])
-        res = sk.mix_mue(ene, t_cm, bool(args.y))
+        res = sk.mix_mue(ene, t_cm)
      ##--close logger
     logging.shutdown()
     
